@@ -1,5 +1,6 @@
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
+#include "about.h"
 
 #include <QtCore/QCoreApplication>
 #include <QProcess>
@@ -306,3 +307,10 @@ void MainWindow::on_stream12_clicked()
     process.start("sh /opt/serviziopubblico/script/p12.sh");
     process.waitForFinished();
 }
+
+void MainWindow::on_actionAbout_triggered()
+{
+    About mAbout;
+    mAbout.setModal(true);
+    mAbout.exec();
+}
